ReactionState class

Constructors

ReactionState({required bool isReactionsTrayOpen, required bool react, required bool close})
const

Properties

close → bool
final
hashCode → int
The hash code for this object.
no setterinherited
isReactionsTrayOpen → bool
final
react → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited