AnimatedReactionOverlay class

Inheritance

Constructors

AnimatedReactionOverlay({Key? key, required double width, required LayerLink layerLink, required Color overlayBackgroundColor, required bool showCloseButton, Widget? customCloseButton, Offset? offset, Alignment? alignment, required AnimationController elementController, required AnimationController overlayController, required List<Reaction> reactions, required OverlayEntry entry})
const

Properties

alignment → Alignment?
The alignment where the pop up is shown
final
customCloseButton → Widget?
A Widget type parameter to display custom close button
final
elementController → AnimationController
final
entry → OverlayEntry
This controls the adding and removal of the pop up from the screen
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
The layerlink is used to attach to the parent widget
final
offset → Offset?
The offset with which the pop up is shown with respect to the child
final
overlayBackgroundColor → Color
The overlay background color of the pop up type: Color
final
overlayController → AnimationController
final
reactions → List<Reaction>
The list of Reaction widgets which are shown in the pop up
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showCloseButton → bool
A bool flag to set whether the close button should be rendered
final
width → double
The width of the reaction pop up
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<AnimatedReactionOverlay>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited